@charset "UTF-8";
:root {
  interpolate-size: allow-keywords;
  --header-height: 15.6rem;
  --header-height-sp: 6rem;
  --font-en: "Noto Serif", serif;
  --font-mincho: "Noto Serif JP", serif;
}

/* Box sizing rules */
*,
*::before,
*::after {
  box-sizing: border-box;
}

/* Remove default margin */
body,
h1,
h2,
h3,
h4,
p,
figure,
blockquote,
dl,
dd {
  margin: 0;
}

/* Remove list styles on ul, ol elements with a list role, which suggests default styling will be removed */
ul[role=list],
ol[role=list] {
  list-style: none;
}

/* Set core root defaults */
html:focus-within {
  scroll-behavior: smooth;
}

/* Set core body defaults */
body {
  min-height: 100vh;
  text-rendering: optimizeSpeed;
  line-height: 1.5;
}

/* A elements that don't have a class get default styles */
a:not([class]) {
  -webkit-text-decoration-skip: ink;
          text-decoration-skip-ink: auto;
}

/* Make images easier to work with */
img,
picture {
  max-width: 100%;
  display: block;
}

/* Inherit fonts for inputs and buttons */
input,
button,
textarea,
select {
  font: inherit;
}

/* Remove all animations and transitions for people that prefer not to see them */
@media (prefers-reduced-motion: reduce) {
  html:focus-within {
    scroll-behavior: auto;
  }
  *,
  *::before,
  *::after {
    animation-duration: 0.01ms !important;
    animation-iteration-count: 1 !important;
    transition-duration: 0.01ms !important;
    scroll-behavior: auto !important;
  }
}
html {
  font-size: 0.6613756614dvw;
  scroll-padding-top: var(--header-height);
  scroll-behavior: smooth;
}
@media all and (max-width: 900px) {
  html {
    font-size: 3.125dvw;
    scroll-padding-top: var(--header-height-sp);
  }
}
@media screen and (min-width: 1512px) {
  html {
    font-size: 10px;
  }
}
@media screen and (max-width: 320px) {
  html {
    font-size: 10px;
  }
}
@media all and (max-width: 900px) {
  html.is-lock {
    scroll-behavior: auto;
  }
}

body {
  color: #132c42;
  background-color: #ffffff;
  font-family: "Noto Sans JP", sans-serif;
  font-size: 1.8rem;
  font-optical-sizing: auto;
  -webkit-font-smoothing: antialiased;
  font-weight: 500;
  line-height: 1.7;
  margin: 0;
  padding: 0;
  overflow-y: scroll;
  overflow-wrap: anywhere;
}
@media all and (max-width: 900px) {
  body {
    font-size: 1.2rem;
    line-height: 1.6;
  }
}

p,
ul,
ol,
dl {
  margin: 0 0 2em;
  padding: 0;
}

a,
button {
  color: #0152a6;
  text-decoration: underline;
  transition-duration: 0.3s;
}
a:hover,
button:hover {
  opacity: 0.8;
  text-decoration: none;
}

img,
svg {
  vertical-align: bottom;
}

img {
  height: auto;
}

input,
textarea,
select {
  font-family: inherit;
}

@media all and (max-width: 900px) {
  .pc-br {
    display: none;
  }
}

.sp-br {
  display: none;
}
@media all and (max-width: 900px) {
  .sp-br {
    display: inline;
  }
}

.wrap {
  display: grid;
  grid-template-rows: auto 1fr auto;
  width: 100%;
  min-width: 320px;
  min-height: 100dvh;
  overflow: clip;
  max-width: 1920px;
  margin-left: auto;
  margin-right: auto;
  box-shadow: 0 0 10rem rgba(0, 0, 0, 0.2);
  padding-top: var(--header-height);
}
@media all and (max-width: 900px) {
  .wrap {
    padding-top: var(--header-height-sp);
  }
}
.is-home .wrap {
  padding-top: 0 !important;
}
@media all and (max-width: 900px) {
  .wrap.is-lock {
    position: fixed;
  }
}

.content {
  overflow: hidden;
}
.content--type2 {
  background-color: #eff3f9;
}
.content__inner {
  padding-bottom: 15rem;
}
@media all and (max-width: 900px) {
  .content__inner {
    padding-bottom: 4rem;
  }
}

.container {
  max-width: 140rem;
  margin-right: auto;
  margin-left: auto;
}
@media all and (max-width: 900px) {
  .container {
    max-width: none;
    padding-left: 2rem;
    padding-right: 2rem;
  }
}
.has-side .container {
  display: flex;
  align-items: flex-start;
  gap: 6rem;
}
@media all and (max-width: 900px) {
  .has-side .container {
    flex-direction: column;
    gap: 4rem;
  }
}

.header {
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  height: var(--header-height);
  z-index: 8;
  background-color: #ffffff;
  border-top: 2rem solid #0152a6;
  transition-duration: 0.3s;
}
@media all and (max-width: 900px) {
  .header {
    height: var(--header-height-sp);
    border-top-width: 0.5rem;
  }
}
.header.is-hidden {
  top: calc(var(--header-height) * -2);
}
@media all and (max-width: 900px) {
  .header.is-hidden {
    top: calc(var(--header-height-sp) * -2);
  }
}
.header.is-scrolled {
  box-shadow: 0 0 1rem rgba(0, 0, 0, 0.15);
}
.header__container {
  display: flex;
  align-items: center;
  height: 100%;
}
.header__col {
  width: 24.6rem;
}
@media all and (max-width: 900px) {
  .header__col {
    width: 10rem;
  }
}
.header__col2 {
  margin: 0 0 0 auto;
}
@media all and (max-width: 900px) {
  .header__col2 {
    display: none;
  }
}
.header__logo {
  width: 24.6rem;
}
@media all and (max-width: 900px) {
  .header__logo {
    width: 10rem;
    margin-left: -1.2rem;
  }
}
.header__logo img {
  width: 100%;
  height: auto;
}
.header__row {
  display: flex;
  align-items: flex-start;
  justify-content: flex-end;
  height: 6rem;
}
.header__nav {
  display: flex;
  gap: 0 4rem;
  margin: 1.6rem 3.2rem 0 0;
}
.header__nav__item {
  margin: 0;
  list-style-type: none;
}
.header__nav__item a {
  display: block;
  padding: 0 1.2rem;
  color: #132c42;
  text-decoration: none;
  font-size: 1.8rem;
  line-height: 1.2;
}
.header__nav2 {
  display: none;
  gap: 0.8rem;
  margin: 0 2.8rem 0 auto;
  align-items: center;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .header__nav2 {
    display: flex;
  }
}
.header__nav2__item {
  width: 4.1rem;
  height: 4.1rem;
}
.header__nav2__item a {
  width: 100%;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  border-radius: 0.5rem;
  color: #fff;
  text-decoration: none;
  font-size: 1rem;
}
.header__nav2__item a span {
  transform: scale(0.8);
}
.header__nav2__item--english a {
  background-color: #0152a6;
}
.header__nav2__item--contact a {
  background-color: #0989a0;
}
.header__english {
  position: relative;
  margin: 0;
  top: -0.2rem;
}
.header__english a {
  background-color: #0152a6;
  display: block;
  border-radius: 0 0 1rem 1rem;
  color: #fff;
  text-decoration: none;
  font-size: 1.8rem;
  line-height: 1.2;
  padding: 0.6rem 2rem 1.2rem;
  width: 23.2rem;
  text-align: center;
}
.header__global {
  height: 7.6rem;
}
@media all and (max-width: 900px) {
  .header__global {
    display: none;
  }
}
.header__global__content {
  position: absolute;
  top: calc(var(--header-height) - 2rem);
  left: 0;
  right: 0;
  margin: 0;
  padding: 0;
  max-height: calc(100vh - var(--header-height));
  display: none;
  height: 0;
  overflow: hidden;
  transition: all 0.3s;
}
.header__global__nav__item:hover .header__global__content {
  display: flex;
  height: auto;
  opacity: 1;
  overflow: visible;
}
@starting-style {
  .header__global__nav__item:hover .header__global__content {
    height: 0;
    opacity: 0;
  }
}
.is-hidden .header__global__content {
  display: none !important;
}
.header__global__content__col {
  position: relative;
  width: 48rem;
}
.header__global__content__col::before {
  content: "";
  position: absolute;
  top: 0;
  left: -100vw;
  right: 0;
  bottom: 0;
  background-color: #0152a6;
  z-index: 1;
}
.header__global__content__col__inner {
  position: relative;
  display: flex;
  justify-content: flex-end;
  width: 100%;
  height: 100%;
  z-index: 2;
  padding: 4.8rem 6.4rem 4.8rem 0;
  color: #fff;
  font-size: 3.2rem;
  font-family: var(--font-en);
  font-weight: 700;
}
.header__global__content__col__inner a {
  color: #fff;
  text-decoration: none;
}
.header__global__content__col2 {
  position: relative;
  flex: 1;
  padding: 1.2rem 0 0;
}
.header__global__content__col2::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: -100vw;
  bottom: 0;
  background-color: #eff3f9;
  z-index: 1;
}
.header__global__content__col2__inner {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  gap: 2.8rem 3rem;
  width: 100%;
  height: 100%;
  z-index: 2;
  padding: 3.6rem 4.8rem 6.4rem;
  overflow-y: auto;
}
.header__global__nav {
  display: flex;
  gap: 4.2rem;
  list-style-type: none;
  margin: 0;
  height: 100%;
}
.header__global__nav__item > a {
  position: relative;
  display: block;
  height: 100%;
  padding-top: 1.2rem;
  color: #18589c;
  font-size: 2.2rem;
  font-weight: 700;
  text-decoration: none;
}
.header__global__nav__item > a::after {
  content: "";
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  width: 0;
  height: 0.4rem;
  background-color: #18589c;
  transition-duration: 0.3s;
}
.header__global__nav__item > a:hover::after {
  width: 100%;
}
.header__global__nav2 {
  width: calc(33.333% - 2rem);
}
.header__global__nav2__ttl > a {
  font-size: 1.9rem;
  font-weight: 700;
  color: #0152a6;
  text-decoration: none;
}
.header__global__nav3 {
  width: 100%;
  display: flex;
  flex-wrap: wrap;
  gap: 2.8rem 3rem;
  margin: 0.8rem 0 0;
  list-style-type: none;
}
.header__global__nav3__item {
  width: calc(33.333% - 2rem);
}
.header__global__nav3__item > a {
  position: relative;
  display: block;
  font-size: 1.7rem;
  color: #132c42;
  text-decoration: none;
}
.header__global__nav2 .header__global__nav3 {
  flex-direction: column;
  gap: 0.4rem 0;
}
.header__global__nav2 .header__global__nav3__item {
  width: auto;
}
.header__global__nav4 {
  display: flex;
  flex-direction: column;
  gap: 0;
  margin: 0;
  list-style-type: none;
}
.header__global__nav4__item {
  margin: 0;
}
.header__global__nav4__item > a {
  position: relative;
  display: block;
  font-size: 1.6rem;
  color: #132c42;
  text-decoration: none;
  padding-left: 2rem;
}
.header__global__nav4__item > a::after {
  content: "-";
  position: absolute;
  top: 0;
  left: 0;
}
.header__global__nav5 {
  display: flex;
  flex-direction: column;
  gap: 0;
  margin: 0;
  list-style-type: none;
}
.header__global__nav5__item {
  margin: 0;
}
.header__global__nav5__item > a {
  position: relative;
  display: block;
  font-size: 1.6rem;
  color: #132c42;
  text-decoration: none;
  padding-left: 2.8rem;
}
.header__global__nav5__item > a::after {
  content: "└";
  position: absolute;
  top: 0;
  left: 0.4rem;
}
.header__hamburger {
  display: none;
}
@media all and (max-width: 900px) {
  .header__hamburger {
    display: block;
    position: absolute;
    top: 0;
    right: 0;
    width: 4.8rem;
    height: 5.5rem;
  }
}
.header__hamburger a {
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
}
.header__hamburger a span {
  display: block;
  width: 100%;
  height: 100%;
  text-indent: -9999rem;
}
.header__hamburger a::before, .header__hamburger a::after,
.header__hamburger a span::before {
  content: "";
  position: absolute;
  left: 0;
  right: 0;
  margin: 0 auto;
  width: 2rem;
  height: 0.2rem;
  background-color: #2369b2;
  transition: 0.3s;
}
.header__hamburger a::before {
  top: 2.1rem;
}
.header__hamburger a::after {
  bottom: 2.1rem;
}
.header__hamburger a span::before {
  top: 50%;
  margin-top: -0.1rem;
}
.header__hamburger a.is-open::before {
  top: 2.35rem;
  transform: rotate(-45deg);
}
.header__hamburger a.is-open::after {
  bottom: 2.5em;
  transform: rotate(45deg);
}
.header__hamburger a.is-open span::before {
  opacity: 0;
}
.is-home .header:not(.is-scrolled) {
  background: transparent;
}
.is-home .header:not(.is-scrolled) .header__logo img {
  filter: drop-shadow(0.2rem 0 0 #fff) drop-shadow(-0.2rem 0 0 #fff) drop-shadow(0 0.2rem 0 #fff) drop-shadow(0 -0.2rem 0 #fff);
}
.is-home .header:not(.is-scrolled) .header__nav__item a {
  color: #fff;
}
.is-home .header:not(.is-scrolled) .header__global__nav__item > a {
  color: #fff;
}
@media all and (max-width: 900px) {
  .header.is-open {
    background-color: #fff !important;
  }
}

.footer {
  padding: 8.4rem 0 6.4rem;
  background-color: #eff3f9;
}
@media all and (max-width: 900px) {
  .footer {
    padding: 4.2rem 0 5.2rem;
  }
}
.footer--type2 {
  background-color: #fff;
}
.footer__row {
  display: flex;
  flex-wrap: wrap;
  gap: 7.8rem;
}
@media all and (max-width: 900px) {
  .footer__row {
    margin: 0;
    gap: 1.8rem;
  }
}
.footer__col {
  flex: 1;
}
@media all and (max-width: 900px) {
  .footer__col {
    flex: auto;
    width: calc(50% - 0.9rem);
  }
}
.footer__nav {
  margin: 0;
}
@media all and (max-width: 900px) {
  .footer__nav {
    width: auto;
    margin: 0;
  }
}
.footer__nav + .footer__nav {
  margin-top: 9rem;
}
@media all and (max-width: 900px) {
  .footer__nav + .footer__nav {
    margin-top: 4rem;
  }
}
.footer__nav a {
  text-decoration: none;
  color: #132c42;
}
.footer__nav > dt {
  padding: 1.2rem;
  font-size: 1.8rem;
  font-weight: 700;
  border-top: 0.2rem dotted #132c42;
  border-bottom: 0.2rem dotted #132c42;
}
@media all and (max-width: 900px) {
  .footer__nav > dt {
    padding: 0.6rem 0.5rem;
    border-top-width: #132c42;
    border-bottom-width: #132c42;
    font-size: 1.2rem;
  }
}
.footer__nav > dt a {
  display: block;
  margin: -1.2rem;
  padding: 1.2rem;
}
@media all and (max-width: 900px) {
  .footer__nav > dt a {
    margin: -0.6rem -0.5rem;
    padding: 0.6rem 0.5rem;
  }
}
.footer__nav > dd {
  padding: 2.4rem 1.2rem 0;
  font-size: 1.6rem;
}
@media all and (max-width: 900px) {
  .footer__nav > dd {
    padding: 0.8rem 0.5rem 0;
  }
}
.footer__nav2 {
  margin: 0;
}
.footer__nav2 + .footer__nav2 {
  margin-top: 3.6rem;
}
@media all and (max-width: 900px) {
  .footer__nav2 + .footer__nav2 {
    margin-top: 1.8rem;
  }
}
.footer__nav2 > dt {
  color: #0152a6;
  font-size: 1.6rem;
  font-weight: 700;
  margin-bottom: 1rem;
}
@media all and (max-width: 900px) {
  .footer__nav2 > dt {
    font-size: 1.2rem;
    margin-bottom: 0.8rem;
  }
}
.footer__nav2 > dt a {
  color: #0152a6;
}
.footer__nav3 {
  display: flex;
  flex-direction: column;
  gap: 0.8rem;
  margin: 0;
  list-style-type: none;
  font-size: 1.6rem;
}
@media all and (max-width: 900px) {
  .footer__nav3 {
    gap: 0.6rem;
    font-size: 1.1rem;
  }
}
.footer__nav3 a {
  display: block;
}
.footer__nav4 {
  display: flex;
  flex-direction: column;
  gap: 0.8rem;
  margin: 1rem 0 0;
  list-style-type: none;
  font-size: 1.4rem;
}
@media all and (max-width: 900px) {
  .footer__nav4 {
    gap: 0.4rem;
    margin: 0.6rem 0 0;
    font-size: 1rem;
  }
}
.footer__nav4 a {
  position: relative;
  display: block;
  position: relative;
  padding-left: 1rem;
}
@media all and (max-width: 900px) {
  .footer__nav4 a {
    padding-left: 0.6rem;
  }
}
.footer__nav4 a::before {
  content: "";
  position: absolute;
  top: 0.8em;
  left: 0;
  width: 0.5rem;
  height: 0.2rem;
  background-color: #132c42;
}
@media all and (max-width: 900px) {
  .footer__nav4 a::before {
    width: 0.3rem;
    height: 1px;
  }
}
.footer__logo {
  margin: 6rem auto 0;
  width: 23.5rem;
}
@media all and (max-width: 900px) {
  .footer__logo {
    margin-top: 4rem;
    width: 18rem;
  }
}
.footer__logo img {
  width: 100%;
  height: auto;
}
.footer__address {
  margin: 3.6rem 0 0;
  text-align: center;
  color: #132c42;
  font-size: 1.4rem;
  line-height: 1.8;
}
@media all and (max-width: 900px) {
  .footer__address {
    margin-top: 2.4rem;
    font-size: 1rem;
  }
}
.footer__copyright {
  margin: 5.2rem 0 0;
  text-align: center;
  color: #132c42;
  font-size: 1.4rem;
}
@media all and (max-width: 900px) {
  .footer__copyright {
    margin-top: 2rem;
    font-size: 1rem;
  }
}

.pagetop {
  position: fixed;
  bottom: 2rem;
  right: 2rem;
  z-index: 10;
  width: 8rem;
  height: 8rem;
}
@media all and (max-width: 900px) {
  .pagetop {
    bottom: 5rem;
    right: 0.8rem;
    width: 3.6rem;
    height: 3.6rem;
  }
}
.pagetop a {
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
  text-indent: -999rem;
  background-color: #80c9c3;
  border-radius: 1rem;
  box-shadow: 0 0 1.2rem rgba(0, 0, 0, 0.3);
}
@media all and (max-width: 900px) {
  .pagetop a {
    border-radius: 0.4rem;
    box-shadow: 0 0 0.4rem rgba(0, 0, 0, 0.3);
  }
}
.pagetop a::before, .pagetop a::after {
  content: "";
  position: absolute;
  top: 2.4rem;
  left: calc(50% - 0.2rem);
  width: 0.4rem;
  height: 3.2rem;
  background-color: #ffffff;
  transform-origin: 50% 0.2rem;
}
@media all and (max-width: 900px) {
  .pagetop a::before, .pagetop a::after {
    top: 1.2rem;
    left: calc(50% - 0.1rem);
    width: 0.2rem;
    height: 1.6rem;
    border-radius: 0.4rem;
  }
}
.pagetop a::before {
  transform: rotate(45deg);
}
.pagetop a::after {
  transform: rotate(-45deg);
}

.drawer {
  display: none;
  position: fixed;
  z-index: 110;
  top: var(--header-height-sp);
  width: 100dvw;
  right: -110dvw;
  bottom: 0;
  background-color: #fff;
  padding: 3.2rem 1.8rem 0;
  overflow-y: auto;
  transition: 0.3s right;
}
@media all and (max-width: 900px) {
  .drawer {
    display: block;
  }
}
.drawer.is-open {
  background-color: #0152a6;
  right: 0;
}
.drawer__inner {
  padding-bottom: 3.2rem;
}
.drawer__navs {
  -moz-column-count: 2;
       column-count: 2;
  -moz-column-gap: 1.8rem;
       column-gap: 1.8rem;
}
.drawer__nav {
  -moz-column-break-inside: avoid;
       break-inside: avoid;
  margin: 0 0 3.2rem;
}
.drawer__nav a {
  text-decoration: none;
  color: #fff;
}
.drawer__nav > dt {
  padding: 0.6rem 0.5rem;
  border-top: 1px solid #fff;
  border-bottom: 1px solid #fff;
  font-size: 1.3rem;
  font-weight: 700;
}
.drawer__nav > dt > a {
  display: block;
  margin: -0.6rem -0.5rem;
  padding: 0.6rem 0.5rem;
}
.drawer__nav > dd {
  padding: 0.8rem 0.5rem 0;
}
.drawer__nav2 {
  margin: 0;
}
.drawer__nav2 + .drawer__nav2 {
  margin-top: 2.4rem;
}
.drawer__nav2 > dt {
  margin-bottom: 0.8rem;
  color: #fff;
  font-size: 1.2rem;
  font-weight: 700;
}
.drawer__nav2 > dt a {
  color: #fff;
}
.drawer__nav3 {
  display: flex;
  flex-direction: column;
  gap: 0.6rem;
  margin: 0;
  list-style-type: none;
  font-size: 1.1rem;
}
.drawer__nav3 > li > a {
  display: block;
}
.drawer__nav4 {
  display: flex;
  flex-direction: column;
  gap: 0.4rem;
  margin: 0.6rem 0 0;
  list-style-type: none;
  font-size: 1rem;
}
.drawer__nav4 > li > a {
  position: relative;
  display: block;
  padding-left: 0.6rem;
}
.drawer__nav4 > li > a::before {
  content: "";
  position: absolute;
  top: 0.8em;
  left: 0;
  width: 0.3rem;
  height: 1px;
  background-color: #fff;
}

.fixed-nav {
  position: fixed;
  z-index: 10;
  right: 50%;
  top: 50%;
  transform: translate(96rem, -30%);
}
@media all and (max-width: 900px) {
  .fixed-nav {
    top: auto;
    left: 0;
    bottom: 0;
    transform: none !important;
  }
}
@media screen and (max-width: 1920px) {
  .fixed-nav {
    right: 0;
    transform: translate(0, -30%);
  }
}
.fixed-nav__list {
  display: flex;
  flex-direction: column;
  gap: 2rem;
  margin: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .fixed-nav__list {
    flex-direction: row;
    gap: 0;
  }
}
@media all and (max-width: 900px) {
  .fixed-nav__list__item {
    flex: 1;
  }
}
.fixed-nav__list__item a {
  position: relative;
  display: flex;
  width: 5.5rem;
  padding: 2rem 1.2rem;
  font-size: 1.8rem;
  font-weight: 700;
  color: #fff;
  text-align: center;
  text-decoration: none;
  line-height: 1.4;
  background-color: #000;
  border-radius: 0.5rem 0 0 0.5rem;
  box-shadow: 0 0 1rem rgba(0, 0, 0, 0.2);
}
@media all and (max-width: 900px) {
  .fixed-nav__list__item a {
    align-items: center;
    justify-content: center;
    width: auto;
    height: 4rem;
    padding: 0;
    font-size: 1.1rem;
    border-radius: 0;
    box-shadow: none;
  }
}
.fixed-nav__list__item--visit a {
  background-color: #0152a6;
}
.fixed-nav__list__item--connect a {
  background-color: #0989a0;
}
.fixed-nav__list__item__inner {
  position: relative;
  display: block;
  padding-top: 5rem;
}
@media all and (max-width: 900px) {
  .fixed-nav__list__item__inner {
    padding-top: 0;
    padding-left: 3.2rem;
  }
}
.fixed-nav__list__item__inner::before {
  content: "";
  position: absolute;
  top: 0;
  left: 50%;
  transform: translateX(-50%);
  width: 4rem;
  height: 4rem;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .fixed-nav__list__item__inner::before {
    top: 50%;
    left: 0;
    transform: translateY(-50%);
    width: 2.4rem;
    height: 2.4rem;
  }
}
.fixed-nav__list__item--visit .fixed-nav__list__item__inner::before {
  background-image: url(../images/ic_visit_001.png);
}
.fixed-nav__list__item--connect .fixed-nav__list__item__inner::before {
  background-image: url(../images/ic_connect_001.png);
}
.breadcrumbs-wrap {
  position: relative;
  z-index: 2;
  padding: 3.6rem 0;
}
@media all and (max-width: 900px) {
  .breadcrumbs-wrap {
    padding: 1.2rem 0;
  }
}

.breadcrumbs {
  font-size: 1.8rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .breadcrumbs {
    font-size: 1.1rem;
  }
}
.breadcrumbs a {
  text-decoration: none;
}

.main {
  position: relative;
}
.has-side .main {
  order: 2;
  flex: 1;
}
@media all and (max-width: 900px) {
  .has-side .main {
    order: 1;
    width: 100%;
  }
}
.main > :last-child {
  margin-bottom: 0;
}
.main__inner {
  position: relative;
  padding: 4.8rem 6rem 16rem;
  border-radius: 1.4rem;
  background-color: #fff;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .main__inner {
    padding: 2rem 1.6rem 4rem;
    border-radius: 0.7rem;
  }
}
.main__inner::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  height: 0.4rem;
  background-color: #0152a6;
}
.main__inner > :first-child {
  margin-top: 0;
}
.main__inner > :last-child {
  margin-bottom: 0;
}

.side {
  position: relative;
}
.has-side .side {
  order: 1;
  width: 30rem;
}
@media all and (max-width: 900px) {
  .has-side .side {
    order: 2;
    /*width: auto;*/
     max-width: 100% !important;
  }
}
.side__inner > :last-child {
  margin-bottom: 0;
}
.side__nav {
  border-radius: 1.4rem;
  overflow: hidden;
  margin: 0;
}
@media all and (max-width: 900px) {
  .side__nav {
    border-radius: 0.7rem;
  }
}
.side__nav + .side__nav {
  margin-top: 2.4rem;
}
@media all and (max-width: 900px) {
  .side__nav + .side__nav {
    margin-top: 2rem;
  }
}
.side__nav__ttl {
  padding: 1.6rem 1.2rem;
  background-color: #0152a6;
  color: #fff;
  font-size: 2.4rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  text-align: center;
}
@media all and (max-width: 900px) {
  .side__nav__ttl {
    font-size: 1.5rem;
    padding: 0.8rem 1.2rem;
  }
}
.side__nav__ttl a {
  display: block;
  margin: -1.6rem -1.2rem;
  padding: 1.6rem 1.2rem;
  color: #fff;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .side__nav__ttl a {
    margin: -0.8rem -1.2rem;
    padding: 0.8rem 1.2rem;
  }
}
.side__nav__tag {
  padding: 1.4rem 1.2rem;
  background-color: #fff;
  border-bottom: 0.2rem solid #e0e7f2;
}
@media all and (max-width: 900px) {
  .side__nav__tag {
    padding: 1.2rem;
  }
}
.side__nav__tag:only-child {
  border-bottom: none;
}
.side__nav__tag > :last-child {
  margin-bottom: 0;
}
.side__nav2 {
  margin: 0;
  list-style-type: none;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .side__nav2 {
    font-size: 1.2rem;
  }
}
.side__nav2__item {
  border-bottom: 0.2rem solid #e0e7f2;
}
.side__nav2__item:last-child {
  border-bottom: none;
}
.side__nav2__item a {
  position: relative;
  display: block;
  padding: 2rem 1.2rem;
  background-color: #fff;
  color: #0152a6;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .side__nav2__item a {
    padding: 1.2rem;
  }
}
.side__nav3 {
  margin: 0;
  list-style-type: none;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .side__nav3 {
    font-size: 1.2rem;
  }
}
.side__nav3__item {
  border-bottom: 0.2rem solid #fff;
}
.side__nav3__item:last-child {
  border-bottom: none;
}
.side__nav3__item a {
  background-color: #dfe8f5;
  padding-left: 2.2rem;
}
.side__nav3__item a::before {
  position: absolute;
  content: "-";
  top: 2rem;
  left: 1.2rem;
}
@media all and (max-width: 900px) {
  .side__nav3__item a::before {
    top: 1.1rem;
  }


}

.side__nav4 {
  margin: 0;
  list-style-type: none;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .side__nav4 {
    font-size: 1.2rem;
  }

}
.side__nav4__item {
  border-bottom: 0.2rem solid #fff;
}
.side__nav4__item:last-child {
  border-bottom: none;
}
.side__nav4__item a {
  background-color: #c2d3ec;
  padding-left: 3.2rem;
}
.side__nav4__item a::before {
  position: absolute;
  content: "└";
  top: 2rem;
  left: 1.2rem;
}
@media all and (max-width: 900px) {
  .side__nav4__item a::before {
    top: 1.1rem;
  }
}

.side__bnr {
  display: flex;
  flex-direction: column;
  gap: 2rem;
  margin: 2.4rem 0 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .side__bnr {
    gap: 1rem;
    margin-top: 2rem;
  }
}
.side__bnr__item a {
  display: block;
  position: relative;
  border-radius: 1.4rem;
  overflow: hidden;
  border: 0.2rem solid #9cb3c9;
}
@media all and (max-width: 900px) {
  .side__bnr__item a {
    border-radius: 0.7rem;
  }
}
.side__bnr__txt {
  position: absolute;
  z-index: 2;
  left: 0;
  right: 0;
  bottom: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 6.8rem;
  background-color: rgba(1, 82, 166, 0.8);
  color: #fff;
  font-size: 2.2rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  line-height: 1.2;
}
@media all and (max-width: 900px) {
  .side__bnr__txt {
    height: 4.2rem;
    font-size: 1.2rem;
  }
}
.side__bnr__img {
  position: relative;
  z-index: 1;
  display: block;
  aspect-ratio: 300/146;
}
.side__bnr__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.ttl {
  position: relative;
  min-height: 13.2rem;
  display: flex;
  justify-content: center;
  align-items: center;
  margin: 0 0 5.8rem;
}
@media all and (max-width: 900px) {
  .ttl {
    overflow: hidden;
    min-height: 3rem;
    margin-bottom: 1.8rem;
  }
}
.ttl__jp {
  position: relative;
  z-index: 2;
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 3.6rem;
  font-size: 4.2rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .ttl__jp {
    gap: 1.6rem;
    font-size: 1.8rem;
  }
}
.ttl__jp::before, .ttl__jp::after {
  content: "";
  width: 19rem;
  height: 1px;
  background-color: #132c42;
}
@media all and (max-width: 900px) {
  .ttl__jp::before, .ttl__jp::after {
    flex: 1;
  }
}
.ttl__en {
  position: absolute;
  inset: 0;
  z-index: 1;
  font-size: 15rem;
  font-family: var(--font-en);
  font-weight: 400;
  line-height: 13.2rem;
  text-align: center;
  color: #f5f6f7;
  margin: -1.8rem 0 0;
  white-space: nowrap;
}
@media all and (max-width: 900px) {
  .ttl__en {
    font-size: 4.2rem;
    line-height: 3rem;
    margin-top: -0.2rem;
  }
}
.ttl--type2 .ttl__jp {
  color: #fff;
}
.ttl--type2 .ttl__jp::before, .ttl--type2 .ttl__jp::after {
  background-color: rgba(255, 255, 255, 0.6);
}
.ttl--type2 .ttl__en {
  color: rgba(255, 255, 255, 0.1);
}

.ttl2 {
  position: relative;
  font-size: 3.2rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  text-align: center;
  color: #18589c;
  margin-bottom: 6rem;
  padding-bottom: 2.4rem;
}
@media all and (max-width: 900px) {
  .ttl2 {
    font-size: 1.8rem;
    margin-bottom: 2rem;
    padding-bottom: 1.6rem;
  }
}
.ttl2::before {
  content: "";
  position: absolute;
  bottom: 0;
  left: 50%;
  transform: translateX(-50%);
  width: 9.6rem;
  height: 0.2rem;
  background-color: #18589c;
}
@media all and (max-width: 900px) {
  .ttl2::before {
    width: 6.4rem;
  }
}

.btn {
  position: relative;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  color: #fff;
  text-decoration: none;
  font-size: 2.2rem;
  font-weight: 700;
  min-width: 22.5rem;
  padding: 1.2rem 1.6rem;
  border: none;
  cursor: pointer;
  border-radius: 0.5rem;
  background: linear-gradient(to bottom, #0152a6 0%, #216ebd 100%);
}
@media all and (max-width: 900px) {
  .btn {
    font-size: 1.2rem;
    min-width: 12rem;
    height: 3.5rem;
  }
}
.btn::before {
  content: "";
  position: absolute;
  bottom: 0.5rem;
  right: 0.5rem;
  width: 1.4rem;
  height: 1.4rem;
  background: #fff;
  clip-path: polygon(100% 0, 0% 100%, 100% 100%);
}
@media all and (max-width: 900px) {
  .btn::before {
    bottom: 0.6rem;
    right: 0.6rem;
    width: 1.1rem;
    height: 1.1rem;
  }
}
.mv {
  position: relative;
  width: 192rem;
  height: 106rem;
  aspect-ratio: 1920/1060;
  margin: 0 auto;
}
@media all and (max-width: 900px) {
  .mv {
    width: 100%;
    height: 42.8rem;
    aspect-ratio: 320/428;
  }
}
.mv__inner {
  position: absolute;
  top: 0;
  left: 50%;
  z-index: 1;
  transform: translateX(-50%);
  width: 192rem;
  height: 100%;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .mv__inner {
    left: 0;
    transform: translateX(0);
    width: 100%;
  }
}
.mv__slides {
  width: 100%;
  height: 100%;
  opacity: 0;
}
.mv__slides.slick-initialized {
  opacity: 1;
}
.mv__slide {
  position: relative;
}
.mv__slide__inner {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 3;
  width: 100%;
  height: 100%;
  padding-top: 16rem;
  display: flex;
  align-items: center;
  justify-content: center;
}
@media screen and (max-width: 1920px) {
  .mv__slide__inner {
    width: 100dvw;
    padding-top: 4rem;
  }
}
.mv__slide__lead {
  margin: 0;
  color: #fff;
  font-family: var(--font-en);
  font-weight: 400;
  text-shadow: 0 0 0.8rem rgba(0, 0, 0, 0.6);
  text-align: center;
}
.mv__slide__lead__txt {
  font-size: 3.8rem;
}
@media all and (max-width: 900px) {
  .mv__slide__lead__txt {
    font-size: 1.4rem;
  }
}
.mv__slide__lead__txt2 {
  font-size: 4.8rem;
  font-style: italic;
}
@media all and (max-width: 900px) {
  .mv__slide__lead__txt2 {
    font-size: 1.7rem;
  }
}
.mv__slide__btns {
  margin: 5.2rem auto 0;
  list-style-type: none;
  display: flex;
  gap: 4rem;
}
@media all and (max-width: 900px) {
  .mv__slide__btns {
    margin-top: 2rem;
    gap: 0.8rem;
  }
}
.mv__slide__btn {
  margin: 0;
  width: 42rem;
  height: 25.4rem;
  background: rgba(0, 0, 0, 0.4);
  border-radius: 2.4rem;
  border: 0.4rem solid #fff;
}
@media all and (max-width: 900px) {
  .mv__slide__btn {
    width: 12.5rem;
    height: 10.8rem;
    border-radius: 1rem;
    border-width: 1px;
  }
}
.mv__slide__btn a {
  width: 100%;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  color: #fff;
  text-decoration: none;
}
.mv__slide__btn__list {
  margin: 0;
  text-align: center;
}
.mv__slide__btn__list > dt {
  position: relative;
  padding-bottom: 1.6rem;
  margin-bottom: 2rem;
  font-size: 3.6rem;
}
@media all and (max-width: 900px) {
  .mv__slide__btn__list > dt {
    font-size: 1.5rem;
    padding-bottom: 0.6rem;
    margin-bottom: 0.4rem;
  }
}
.mv__slide__btn__list > dt::before {
  content: "";
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  margin: 0 auto;
  width: 7.8rem;
  height: 0.3rem;
  background-color: #0152a6;
}
@media all and (max-width: 900px) {
  .mv__slide__btn__list > dt::before {
    width: 3.2rem;
    height: 1px;
  }
}
.mv__slide__btn__list > dd {
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .mv__slide__btn__list > dd {
    font-size: 1rem;
    transform: scale(0.8);
    min-height: 4.8em;
  }
}
.mv__slide__movie {
  width: 100%;
  height: 100%;
  position: relative;
}
@media screen and (max-width: 1920px) {
  .mv__slide__movie {
    width: 100dvw;
  }
}
.mv__slide__movie::before {
  content: "";
  position: absolute;
  inset: 0;
  z-index: 2;
  background-color: rgba(0, 0, 0, 0.2);
}
.mv__slide__movie video {
  position: absolute;
  top: 0;
  left: 50%;
  z-index: 1;
  transform: translateX(-50%);
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.mv__slide__img {
  position: relative;
  z-index: 3;
}
.mv__slide__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
  -o-object-position: 50% 50%;
     object-position: 50% 50%;
}
.mv__slide__img__pc {
  display: block !important;
}
@media all and (max-width: 900px) {
  .mv__slide__img__pc {
    display: none !important;
  }
}
.mv__slide__img__sp {
  display: none !important;
}
@media all and (max-width: 900px) {
  .mv__slide__img__sp {
    display: block !important;
  }
}
.mv .slick-list,
.mv .slick-track {
  height: 100%;
}

.mv2 {
  position: relative;
  width: 100%;
  height: 40rem;
  display: flex;
  align-items: center;
  justify-content: center;
}
@media all and (max-width: 900px) {
  .mv2 {
    height: 17rem;
  }
}
.mv2__inner {
  position: relative;
  z-index: 3;
  text-align: center;
  line-height: 1.4;
  display: flex;
  width: 100%;
  flex-direction: column;
  justify-content: center;
  height: 15rem;
}
@media all and (max-width: 900px) {
  .mv2__inner {
    padding-top: 1.8rem;
  }
}
.mv2__jp {
  position: absolute;
  left: 0;
  right: 0;
  font-size: 4.6rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  color: #ffffff;
  text-shadow: 0 0 1.2rem rgba(0, 0, 0, 0.65);
  margin: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 3.6rem;
}
@media all and (max-width: 900px) {
  .mv2__jp {
    left: 2rem;
    right: 2rem;
    gap: 1.6rem;
    font-size: 1.8rem;
    text-shadow: 0 0 0.6rem rgba(0, 0, 0, 0.65);
  }
}
.mv2__jp::before, .mv2__jp::after {
  content: "";
  width: 19rem;
  height: 1px;
  background-color: rgba(255, 255, 255, 0.6);
}
@media all and (max-width: 900px) {
  .mv2__jp::before, .mv2__jp::after {
    flex: 1;
  }
}
.mv2__en {
  font-size: 15rem;
  font-family: var(--font-en);
  font-weight: 400;
  line-height: 1;
  color: rgba(245, 246, 247, 0.3);
  mix-blend-mode: multiply;
  margin: 0;
}
@media all and (max-width: 900px) {
  .mv2__en {
    font-size: 4.2rem;
  }
}
.mv2__img {
  position: absolute;
  inset: 0;
  z-index: 1;
}
.mv2__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
@media all and (max-width: 900px) {
  .mv2__img__pc {
    display: none;
  }
}
.mv2__img__sp {
  display: none;
}
@media all and (max-width: 900px) {
  .mv2__img__sp {
    display: block;
  }
}

.emergency {
  padding: 1.2rem 0 1.8rem;
  background-color: #d25856;
  font-size: 3.2rem;
  color: #fff;
  text-align: center;
}
@media all and (max-width: 900px) {
  .emergency {
    padding: 0.6rem 0 0.8rem;
    font-size: 1.2rem;
  }
}
.emergency p {
  margin: 0;
}
.emergency a {
  color: #fff;
}

.message {
  padding-top: 9.2rem;
}
@media all and (max-width: 900px) {
  .message {
    padding-top: 4rem;
  }
}
.message__ttl2 {
  display: table;
  width: 100%;
  background: #0152a6;
  color: #fff;
  font-size: 1.8rem;
  line-height: 1.8;
  border-radius: 0.4rem;
  margin-bottom: 2rem;
  padding: 0.6rem 1.8rem;
}
@media all and (max-width: 900px) {
  .message__ttl2 {
    font-size: 1rem;
    border-radius: 0.2rem;
    margin-bottom: 0.8rem;
    padding: 0.2rem 1rem 0.4rem;
  }
}
.message__row {
  display: flex;
  align-items: flex-start;
  gap: 4.8rem;
}
@media all and (max-width: 900px) {
  .message__row {
    flex-direction: column-reverse;
    gap: 3.2rem;
  }
}
.message__col {
  width: 52.5rem;
}
@media all and (max-width: 900px) {
  .message__col {
    width: 100%;
  }
}
.message__col2 {
  flex: 1;
  aspect-ratio: 560/315;
  border-radius: 2rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .message__col2 {
    width: 100%;
    border-radius: 0.8rem;
  }
}
.message__col2 iframe {
  width: 100%;
  height: 100%;
}
.message__sec a {
  color: #132c42;
  text-decoration: none;
}
.message__sec + .message__sec {
  margin-top: 4rem;
}
@media all and (max-width: 900px) {
  .message__sec + .message__sec {
    margin-top: 2rem;
  }
}
.message__date {
  margin-bottom: 0;
  font-size: 1.8rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .message__date {
    font-size: 1.1rem;
  }
}
.message__txt {
  margin-bottom: 0;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .message__txt {
    font-size: 1.1rem;
  }
}
.message__link {
  margin-top: 10rem;
  background-color: #0152a6;
  padding: 10rem 0;
}
@media all and (max-width: 900px) {
  .message__link {
    margin-top: 4rem;
    padding: 2.8rem 0;
  }
}
.message__btn {
  display: flex;
  justify-content: center;
  gap: 6rem;
  margin-bottom: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .message__btn {
    gap: 1.6rem;
  }
}
.message__btn__item {
  width: 65rem;
}
@media all and (max-width: 900px) {
  .message__btn__item {
    width: auto;
    flex: 1;
  }
}
.message__btn__item a {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 12rem;
  border-radius: 1rem;
  background: linear-gradient(to bottom, #d5e6ff 0%, #ffffff 100%);
  text-decoration: none;
  font-size: 2.8rem;
  font-weight: 700;
  color: #0152a6;
}
@media all and (max-width: 900px) {
  .message__btn__item a {
    height: 100%;
    padding: 5.6rem 1.2rem 1rem;
    border-radius: 0.4rem;
    font-size: 1.2rem;
  }
}
.message__btn__item a::before {
  content: "";
  position: absolute;
  bottom: 0.8rem;
  right: 0.8rem;
  width: 2.4rem;
  height: 2.4rem;
  background: #0152a6;
  clip-path: polygon(100% 0, 0% 100%, 100% 100%);
}
@media all and (max-width: 900px) {
  .message__btn__item a::before {
    bottom: 0.5rem;
    right: 0.5rem;
    width: 1.1rem;
    height: 1.1rem;
  }
}
.message__btn__item__inner {
  position: relative;
  display: inline-block;
  padding-left: 12.3rem;
}
@media all and (max-width: 900px) {
  .message__btn__item__inner {
    position: static;
    padding-left: 0;
    text-align: center;
  }
}
.message__btn__item__inner::before {
  content: "";
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  margin: auto 0;
  width: 9.8rem;
  height: 9.8rem;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .message__btn__item__inner::before {
    top: 1rem;
    bottom: auto;
    right: 0;
    margin: 0 auto;
    width: 4.3rem;
    height: 4.3rem;
  }
}
.message__btn__item--live .message__btn__item__inner::before {
  background-image: url(../images/ic_live_001.png);
}
.message__btn__item--list .message__btn__item__inner::before {
  background-image: url(../images/ic_list_001.png);
}
.message__tomoshibi {
  padding: 10rem 0 16rem;
}
@media all and (max-width: 900px) {
  .message__tomoshibi {
    padding: 4rem 0 5.2rem;
  }
}
.message__tomoshibi__ttl {
  display: flex;
  flex-direction: column-reverse;
  align-items: center;
  font-family: var(--font-en);
  margin-bottom: 5.4rem;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__ttl {
    margin-bottom: 2rem;
  }
}
.message__tomoshibi__ttl__jp {
  margin-bottom: 0;
  font-size: 3.2rem;
  font-weight: 700;
  color: #18589c;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__ttl__jp {
    font-size: 1.5rem;
  }
}
.message__tomoshibi__ttl__en {
  margin-bottom: 0;
  font-size: 1.8rem;
  color: #99a8b6;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__ttl__en {
    font-size: 1rem;
  }
}
.message__tomoshibi__list {
  margin-bottom: 6.4rem;
  list-style-type: none;
  border-top: 0.2rem solid #99a8b6;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__list {
    margin: 0 -2rem 4rem;
  }
}
.message__tomoshibi__list__item {
  border-bottom: 0.2rem solid #99a8b6;
}
.message__tomoshibi__list__item a {
  display: flex;
  align-items: center;
  gap: 2.8rem;
  padding: 4rem 6rem;
  text-decoration: none;
  line-height: 1.4;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__list__item a {
    flex-wrap: wrap;
    gap: 0.8rem 1.2rem;
    padding: 1.8rem 2rem;
  }
}
.message__tomoshibi__list__date {
  font-size: 1.8rem;
  color: #99a8b6;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__list__date {
    font-size: 1rem;
  }
}
.message__tomoshibi__list__label {
  font-size: 1.8rem;
  width: 13rem;
  text-align: center;
  background-color: #99a8b6;
  color: #fff;
  padding: 0.25rem 1rem 0.35rem;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__list__label {
    font-size: 1rem;
    width: 7rem;
    padding: 0.2rem 0.8rem 0.3rem;
  }
}
.message__tomoshibi__list__txt {
  flex: 1;
  font-size: 2.2rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__list__txt {
    flex: auto;
    width: 100%;
    font-size: 1.2rem;
  }
}
.message__tomoshibi__btn {
  margin-bottom: 0;
  text-align: right;
}
@media all and (max-width: 900px) {
  .message__tomoshibi__btn {
    text-align: center;
  }
}

.message2__countdown {
  margin-bottom: 5.6rem;
  border: 0.3rem solid #0152a6;
  border-radius: 1rem;
  background-color: #fff;
}
@media all and (max-width: 900px) {
  .message2__countdown {
    margin-bottom: 3rem;
    border-width: 0.2rem;
    border-radius: 0.5rem;
  }
}
.message2__countdown__txt {
  margin: 0;
  padding: 2.6rem 4rem;
  background-color: #0152a6;
  font-size: 3.2rem;
  line-height: 1.2;
  color: #fff;
  text-align: center;
}
@media all and (max-width: 900px) {
  .message2__countdown__txt {
    padding: 0.8rem 2rem 1.2rem;
    font-size: 1.4rem;
  }
}
.message2__countdown__time {
  display: flex;
  align-items: baseline;
  justify-content: center;
  padding: 1.2rem 4rem 2.4rem;
  color: #0152a6;
  line-height: 1.2;
}
@media all and (max-width: 900px) {
  .message2__countdown__time {
    padding: 0.4rem 2rem 1rem;
  }
}
.message2__countdown__num {
  margin-left: 2rem;
  font-size: 6rem;
}
@media all and (max-width: 900px) {
  .message2__countdown__num {
    margin-left: 0.5rem;
    font-size: 2.8rem;
  }
}
.message2__countdown__num:first-child {
  margin-left: 0;
}
.message2__countdown__unit {
  font-size: 3.2rem;
}
@media all and (max-width: 900px) {
  .message2__countdown__unit {
    font-size: 1.4rem;
  }
}
.message2__lead {
  margin-bottom: 5.6rem;
  font-size: 1.8rem;
  text-align: center;
}
@media all and (max-width: 900px) {
  .message2__lead {
    margin-bottom: 3rem;
    font-size: 1.2rem;
  }
}
.message2__list {
  display: flex;
  flex-direction: column;
  gap: 4rem;
  margin: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .message2__list {
    gap: 2.4rem;
  }
}
.message2__list__item a {
  position: relative;
  display: flex;
  align-items: flex-start;
  gap: 4.5rem;
  padding: 6rem;
  background-color: #fff;
  border-radius: 1rem;
  box-shadow: 0 0 4rem rgba(35, 88, 143, 0.3);
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .message2__list__item a {
    flex-direction: column;
    gap: 1.6rem;
    padding: 2rem 2rem 3rem;
    border-radius: 0.5rem;
    box-shadow: 0 0 2rem rgba(35, 88, 143, 0.3);
  }
}
.message2__list__item a::before {
  content: "";
  position: absolute;
  right: 2rem;
  bottom: 2rem;
  width: 3rem;
  height: 3rem;
  background-color: #0152a6;
  clip-path: polygon(100% 0%, 100% 100%, 0% 100%);
}
@media all and (max-width: 900px) {
  .message2__list__item a::before {
    right: 1rem;
    bottom: 1rem;
    width: 1.5rem;
    height: 1.5rem;
  }
}
.message2__list__body {
  order: 2;
  flex: 1;
}
.message2__list__img {
  order: 1;
  width: 40.2rem;
  aspect-ratio: 402/226;
  border-radius: 1rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .message2__list__img {
    width: auto;
    border-radius: 0.5rem;
  }
}
.message2__list__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.message2__date {
  margin-bottom: 1.4rem;
  font-size: 1.8rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .message2__date {
    margin-bottom: 1.2rem;
    font-size: 1.2rem;
  }
}
.message2__sec + .message2__sec {
  margin-top: 4rem;
}
@media all and (max-width: 900px) {
  .message2__sec + .message2__sec {
    margin-top: 2rem;
  }
}
.message2__ttl {
  margin-bottom: 2.4rem;
  font-size: 2.8rem;
  font-family: var(--font-mincho);
}
@media all and (max-width: 900px) {
  .message2__ttl {
    margin-bottom: 1.8rem;
    font-size: 1.5rem;
  }
}
.message2__ttl2 {
  display: table;
  min-width: 13rem;
  text-align: center;
  background: #0152a6;
  color: #fff;
  font-size: 1.8rem;
  line-height: 1.2;
  border-radius: 0.4rem;
  margin-bottom: 2rem;
  padding: 0.6rem 1.8rem 0.8rem;
}
@media all and (max-width: 900px) {
  .message2__ttl2 {
    min-width: 7rem;
    font-size: 1rem;
    border-radius: 0.2rem;
    margin-bottom: 0.8rem;
    padding: 0.2rem 1rem 0.4rem;
  }
}
.message2__txt {
  margin-bottom: 0;
  font-size: 1.8rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .message2__txt {
    font-size: 1.2rem;
  }
}

.news {
  position: relative;
  padding: 9.4rem 0 16rem;
  background-color: #f3faf9;
}
@media all and (max-width: 900px) {
  .news {
    padding: 4rem 0 5.2rem;
  }
}
.news::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  z-index: 1;
  height: 54.2rem;
  background: linear-gradient(to bottom, #0152a6 0%, #216ebd 100%);
}
@media all and (max-width: 900px) {
  .news::before {
    height: 23rem;
  }
}
.news__container {
  position: relative;
  z-index: 2;
}
.news__slide {
  position: relative;
  margin: 13rem -2rem 6.2rem;
}
@media all and (max-width: 900px) {
  .news__slide {
    margin-top: 2.8rem;
    margin-bottom: 7.2rem;
  }
}
.news__slide__item {
  padding: 0 2rem;
}
.news__slide__item a {
  position: relative;
  display: block;
  text-decoration: none;
  border-radius: 2rem;
  overflow: hidden;
  color: #fff;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .news__slide__item a {
    border-radius: 0.8rem;
  }
}
.news__slide__img {
  position: relative;
  z-index: 1;
  aspect-ratio: 440/400;
}
@media all and (max-width: 900px) {
  .news__slide__img {
    aspect-ratio: 280/194;
  }
}
.news__slide__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.news__slide__body {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 2;
  min-height: 22rem;
  padding: 1.6rem 3rem;
  background-color: rgba(0, 0, 0, 0.6);
  display: flex;
  flex-direction: column;
  justify-content: center;
}
@media all and (max-width: 900px) {
  .news__slide__body {
    min-height: 0;
    padding: 1.4rem;
  }
}
.news__slide__date {
  position: relative;
  margin-bottom: 1.6rem;
  padding-bottom: 2rem;
  font-size: 2.4rem;
  text-align: center;
}
@media all and (max-width: 900px) {
  .news__slide__date {
    margin-bottom: 1rem;
    padding-bottom: 1rem;
    font-size: 1rem;
  }
}
.news__slide__date::before {
  content: "";
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  margin: 0 auto;
  width: 7rem;
  height: 0.2rem;
  background-color: #99a8b6;
}
@media all and (max-width: 900px) {
  .news__slide__date::before {
    width: 3.6rem;
    height: 1px;
  }
}
.news__slide__txt {
  display: -webkit-box;
  -webkit-box-orient: vertical;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-line-clamp: 2;
  margin-bottom: 0;
  font-size: 2.4rem;
}
@media all and (max-width: 900px) {
  .news__slide__txt {
    font-size: 1.1rem;
  }
}
.news__slide .slick-arrow {
  position: absolute;
  top: -10rem;
  width: 5rem;
  height: 5rem;
  background: none;
  outline: none;
  text-indent: -999rem;
  border: 0.2rem solid #fff;
  border-radius: 50%;
  cursor: pointer;
  transition-duration: 0.3s;
}
@media all and (max-width: 900px) {
  .news__slide .slick-arrow {
    top: auto;
    bottom: -4.8rem;
    width: 2.6rem;
    height: 2.6rem;
    border-width: 1px;
    border-color: #0152a6;
  }
}
.news__slide .slick-arrow:hover {
  opacity: 0.8;
}
.news__slide .slick-arrow::before, .news__slide .slick-arrow::after {
  content: "";
  position: absolute;
  top: calc(50% - 0.1rem);
  left: calc(50% - 0.8rem);
  width: 1.6rem;
  height: 0.2rem;
  border-radius: 9999px;
  background-color: #fff;
  transform-origin: calc(100% - 0.1rem) 50%;
}
@media all and (max-width: 900px) {
  .news__slide .slick-arrow::before, .news__slide .slick-arrow::after {
    width: 0.8rem;
    left: calc(50% - 0.4rem);
    background-color: #0152a6;
  }
}
.news__slide .slick-arrow::before {
  transform: rotate(42.5deg);
}
.news__slide .slick-arrow::after {
  transform: rotate(-42.5deg);
}
.news__slide .slick-prev {
  right: 8.6rem;
}
@media all and (max-width: 900px) {
  .news__slide .slick-prev {
    right: auto;
    left: 12.4rem;
  }
}
.news__slide .slick-prev::before, .news__slide .slick-prev::after {
  transform-origin: 1px 50%;
}
.news__slide .slick-next {
  right: 2rem;
}
@media all and (max-width: 900px) {
  .news__slide .slick-next {
    right: 12.4rem;
  }
}
.news__slide .slick-next::before, .news__slide .slick-next::after {
  transform-origin: calc(100% - 0.1rem) 50%;
}
.news__btn {
  text-align: right;
  margin: 0;
}
@media all and (max-width: 900px) {
  .news__btn {
    text-align: center;
  }
}

.news2__lead {
  margin-bottom: 5.6rem;
  font-size: 1.8rem;
  text-align: center;
}
@media all and (max-width: 900px) {
  .news2__lead {
    margin-bottom: 3rem;
    font-size: 1.2rem;
  }
}
.news2__list {
  display: flex;
  flex-direction: column;
  gap: 4rem;
  margin: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .news2__list {
    gap: 2.4rem;
  }
}
.news2__list__item a {
  position: relative;
  display: flex;
  align-items: flex-start;
  gap: 4.5rem;
  padding: 6rem;
  background-color: #fff;
  border-radius: 1rem;
  box-shadow: 0 0 4rem rgba(35, 88, 143, 0.3);
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .news2__list__item a {
    flex-direction: column;
    gap: 1.6rem;
    padding: 2rem 2rem 3rem;
    border-radius: 0.5rem;
    box-shadow: 0 0 2rem rgba(35, 88, 143, 0.3);
  }
}
.news2__list__item a::before {
  content: "";
  position: absolute;
  right: 2rem;
  bottom: 2rem;
  width: 3rem;
  height: 3rem;
  background-color: #0152a6;
  clip-path: polygon(100% 0%, 100% 100%, 0% 100%);
}
@media all and (max-width: 900px) {
  .news2__list__item a::before {
    right: 1rem;
    bottom: 1rem;
    width: 1.5rem;
    height: 1.5rem;
  }
}
.news2__list__body {
  order: 2;
  flex: 1;
}
.news2__list__img {
  order: 1;
  width: 40rem;
  aspect-ratio: 400/320;
  border-radius: 1rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .news2__list__img {
    width: auto;
    border-radius: 0.5rem;
  }
}
.news2__list__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.news2__list__date {
  margin-bottom: 1.4rem;
  font-size: 1.8rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .news2__list__date {
    margin-bottom: 1.2rem;
    font-size: 1rem;
  }
}
.news2__list__ttl {
  margin-bottom: 2.4rem;
  font-size: 2.8rem;
  font-weight: 700;
  font-family: var(--font-mincho);
  color: #18589c;
}
@media all and (max-width: 900px) {
  .news2__list__ttl {
    margin-bottom: 1.4rem;
    font-size: 1.5rem;
  }
}
.news2__list__txt {
  margin-bottom: 0;
  font-size: 1.8rem;
  color: #132c42;
}
@media all and (max-width: 900px) {
  .news2__list__txt {
    font-size: 1.2rem;
  }
}

.connect {
  position: relative;
  padding: 9rem 0 10rem;
}
@media all and (max-width: 900px) {
  .connect {
    padding: 4.2rem 0 3.6rem;
  }
}
.connect::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  z-index: 2;
  height: 55.3rem;
  background: url(../images/connect_bg_001.jpg) no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .connect::before {
    height: 39.8rem;
  }
}
.connect::after {
  content: "";
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 1;
  height: 86.4rem;
  background: linear-gradient(to bottom, #0152a6 0%, #216ebd 100%);
}
@media all and (max-width: 900px) {
  .connect::after {
    height: 34.2rem;
  }
}
.connect--type2 {
  padding-top: 3.6rem;
}
@media all and (max-width: 900px) {
  .connect--type2 {
    padding-top: 1.2rem;
  }
}
.connect--type2::before {
  content: none;
}
.connect__container {
  position: relative;
  z-index: 3;
}
.connect__lead {
  font-size: 1.8rem;
  text-align: center;
  margin-bottom: 5.2rem;
}
@media all and (max-width: 900px) {
  .connect__lead {
    font-size: 1.2rem;
    margin-bottom: 1.6rem;
  }
}
.connect__block {
  display: flex;
  flex-wrap: wrap;
  gap: 4rem;
}
@media all and (max-width: 900px) {
  .connect__block {
    gap: 1.6rem;
  }
}
.connect__block a {
  color: #fff;
  text-decoration: none;
}
.connect__block__item {
  position: relative;
  aspect-ratio: 680/490;
  width: calc(50% - 2rem);
  border-radius: 2rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {

  .connect__block__item {
    position: relative;
    aspect-ratio: 270 / 170;
    width: 100%;
    border-radius: 2rem;
    overflow: hidden;
}
.connect__block__item--wide {
  aspect-ratio: 270 / 170 !important;
  width: 100%;
}


.connect_page .connect__block__item {
    aspect-ratio: 280/170 !important;
    width: 100% !important;
    border-radius: 0.8rem;
  }
}



.connect_page .connect__block__item--wide {
  aspect-ratio: 800/490;
  width: 100%;
}

@media all and (max-width: 900px) {

.connect_page .connect__block__item {
        aspect-ratio: 180 / 170 !important;
        width: 100% !important;
        border-radius: 0.8rem;
    }

.connect_page .connect__block__body {
          min-height: 0rem !important;
        padding: 0.5rem;
        margin: 0;
    }

}


.connect__block__item--wide {
aspect-ratio: 1400/490;
  width: 100%;
}
.connect__block__body {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 2;
  display: flex;
  flex-direction: column;
  align-items: center;
  min-height: 18rem;
  padding: 3rem 2.4rem 2.4rem;
  background-color: rgba(0, 0, 0, 0.6);
  color: #fff;
}
@media all and (max-width: 900px) {
  .connect__block__body {
    min-height: 0 !important;
    padding: 1.6rem 1.2rem;
  }
}
.connect__block__body > a {
  display: flex;
  flex-direction: column;
  align-items: center;
}
.connect__block__item--wide .connect__block__body {
  min-height: 16rem;
}
.connect__block__ttl {
  font-size: 3.2rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  margin-bottom: 0.8rem;
}
@media all and (max-width: 900px) {
  .connect__block__ttl {
    font-size: 1.4rem;
    margin-bottom: 0.4rem;
  }
}
.connect__block__txt {
  font-size: 1.8rem;
  margin-bottom: 0;
  text-align: center;
}
@media all and (max-width: 900px) {
  .connect__block__txt {
    font-size: 0.9rem;
  }
}
.connect__block__img {
  position: absolute;
  inset: 0;
  z-index: 1;
}
@media all and (max-width: 900px) {
  .connect__block__img__pc {
    display: none;
  }
}
.connect__block__img__sp {
  display: none;
}
@media all and (max-width: 900px) {
  .connect__block__img__sp {
    display: inline;
  }
}
.connect__block__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}

.guide {
  padding: 10rem 0 16rem;
}
@media all and (max-width: 900px) {
  .guide {
    padding: 4.2rem 0 5.2rem;
  }
}
.guide__list {
  display: flex;
  gap: 3.8rem;
  justify-content: center;
  margin-bottom: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .guide__list {
    flex-direction: column;
    gap: 1.6rem;
  }
}
.guide__list__item {
  position: relative;
  width: 44rem;
  aspect-ratio: 440/490;
  border-radius: 2rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .guide__list__item {
    width: 100%;
    aspect-ratio: 656/310;
    border-radius: 0.8rem;
  }
}
.guide__list__item a {
  color: #fff;
  text-decoration: none;
}
.guide__list__txt {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: 15.6rem;
  display: flex;
  align-items: center;
  justify-content: center;
  flex-direction: column-reverse;
  background-color: rgba(0, 0, 0, 0.6);
}
@media all and (max-width: 900px) {
  .guide__list__txt {
    height: 6.4rem;
  }
}
.guide__list__txt__jp {
  margin: 0;
  font-size: 3.2rem;
  font-weight: 700;
  font-family: var(--font-mincho);
}
@media all and (max-width: 900px) {
  .guide__list__txt__jp {
    font-size: 1.4rem;
  }
}
.guide__list__txt__en {
  margin: 0;
  font-size: 1.8rem;
  font-family: var(--font-en);
}
@media all and (max-width: 900px) {
  .guide__list__txt__en {
    font-size: 1rem;
  }
}
.guide__list__img {
  width: 100%;
  height: 100%;
}
@media all and (max-width: 900px) {
  .guide__list__img__pc {
    display: none;
  }
}
.guide__list__img__sp {
  display: none;
}
@media all and (max-width: 900px) {
  .guide__list__img__sp {
    display: inline;
  }
}
.guide__list__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.contact {
  padding: 7.8rem 0 16rem;
  background: url(../images/contact_bg_001.jpg) no-repeat 50% 0;
  background-size: 192rem 49.3rem;
}
@media all and (max-width: 900px) {
  .contact {
    padding: 4.2rem 0 5.2rem;
    background-size: auto 21.3rem;
  }
}
.contact__lead {
  font-size: 1.8rem;
  text-align: center;
  margin-bottom: 10rem;
}
@media all and (max-width: 900px) {
  .contact__lead {
    font-size: 1.1rem;
    margin-bottom: 4rem;
  }
}
.contact__btn {
  display: flex;
  align-items: center;
  gap: 4.2rem;
  list-style-type: none;
  margin: 0;
}
@media all and (max-width: 900px) {
  .contact__btn {
    flex-direction: column;
    gap: 1.6rem;
  }
}
.contact__btn__item {
  width: 44rem;
  height: 17.8rem;
}
@media all and (max-width: 900px) {
  .contact__btn__item {
    width: 100%;
    height: 6.8rem;
  }
}
.contact__btn__item a {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  border-radius: 2rem;
  background: linear-gradient(to bottom, #0152a6 0%, #216ebd 100%);
  color: #fff;
  text-decoration: none;
}
@media all and (max-width: 900px) {
  .contact__btn__item a {
    border-radius: 0.8rem;
  }
}
.contact__btn__item a::before {
  content: "";
  position: absolute;
  bottom: 1.2rem;
  right: 1.2rem;
  width: 1.8rem;
  height: 1.8rem;
  background: #fff;
  clip-path: polygon(100% 0, 0% 100%, 100% 100%);
}
@media all and (max-width: 900px) {
  .contact__btn__item a::before {
    bottom: 0.6rem;
    right: 0.6rem;
    width: 1.1rem;
    height: 1.1rem;
  }
}
.contact__btn__inner {
  position: relative;
  display: block;
  font-size: 2.8rem;
  font-weight: 700;
  line-height: 1.4;
  padding-left: 11.6rem;
}
@media all and (max-width: 900px) {
  .contact__btn__inner {
    position: static;
    font-size: 1.3rem;
    padding: 0 2.4rem 0 7.8rem;
    text-align: center;
  }
}
.contact__btn__inner::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  bottom: 0;
  margin: auto 0;
  width: 9.8rem;
  height: 9.8rem;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}
@media all and (max-width: 900px) {
  .contact__btn__inner::before {
    left: 3.2rem;
    width: 4.2rem;
    height: 4.2rem;
  }
}
.contact__btn__item--contact .contact__btn__inner::before {
  background-image: url(../images/ic_contact_001.png);
}
.contact__btn__item--request .contact__btn__inner::before {
  background-image: url(../images/ic_request_001.png);
}
.contact__btn__item--access .contact__btn__inner::before {
  background-image: url(../images/ic_access_001.png);
}
.contact__row {
  display: flex;
  gap: 4rem;
  margin-top: 10rem;
}
@media all and (max-width: 900px) {
  .contact__row {
    flex-direction: column;
    gap: 1.6rem;
    margin-top: 4.4rem;
  }
}
.contact__col {
  flex: 1;
}
.contact__map {
  position: relative;
  width: 100%;
  aspect-ratio: 680/343;
  border-radius: 2rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .contact__map {
    aspect-ratio: 280/198;
    border-radius: 0.8rem;
  }
}
.contact__map iframe {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
.contact__info {
  border: 0.2rem solid #9cb3c9;
  border-radius: 2rem;
  height: 100%;
  padding: 3.6rem 4.8rem;
}
@media all and (max-width: 900px) {
  .contact__info {
    border-radius: 0.8rem;
    padding: 2rem 1.6rem;
  }
}
.contact__info__ttl {
  font-size: 3.2rem;
  font-weight: 700;
  font-family: var(--font-mincho);
  color: #18589c;
  margin-bottom: 1.2rem;
}
@media all and (max-width: 900px) {
  .contact__info__ttl {
    font-size: 1.3rem;
    margin-bottom: 0.6rem;
  }
}
.contact__info__address {
  font-size: 2.4rem;
  line-height: 1.4;
  margin-bottom: 1.2rem;
}
@media all and (max-width: 900px) {
  .contact__info__address {
    font-size: 1rem;
    margin-bottom: 1.8rem;
  }
}
.contact__info__tel {
  font-size: 2.4rem;
  line-height: 1.4;
  margin-bottom: 0;
}
@media all and (max-width: 900px) {
  .contact__info__tel {
    display: none;
  }
}
.contact__info__tel__strong {
  font-size: 4.8rem;
  color: #0152a6;
  text-decoration: none;
}
.contact__info__tel2 {
  display: none;
  margin-bottom: 1.4rem;
}
@media all and (max-width: 900px) {
  .contact__info__tel2 {
    display: block;
  }
}
.contact__info__tel2 a {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  padding-right: 3rem;
  text-align: center;
  height: 6rem;
  border-radius: 0.8rem;
  background: linear-gradient(to bottom, #0152a6 0%, #216ebd 100%);
  color: #fff;
  font-size: 1.3rem;
  font-weight: 700;
  text-decoration: none;
}
.contact__info__tel2 a::before {
  content: "";
  position: absolute;
  bottom: 0.6rem;
  right: 0.6rem;
  width: 1.1rem;
  height: 1.1rem;
  background: #fff;
  clip-path: polygon(100% 0, 0% 100%, 100% 100%);
}
.contact__info__tel2__inner {
  position: relative;
  display: inline-block;
  padding-left: 5.2rem;
}
.contact__info__tel2__inner::before {
  content: "";
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  margin: auto 0;
  width: 3.4rem;
  height: 3.4rem;
  background: url(../images/ic_tel_001.png) no-repeat 0 0;
  background-size: 100% 100%;
}
.contact__info__tel2__sub {
  font-size: 1.1rem;
}
.contact__info__fax {
  font-size: 2.4rem;
  line-height: 1.4;
  margin-bottom: 0;
}
@media all and (max-width: 900px) {
  .contact__info__fax {
    font-size: 1.1rem;
  }
}

.boxes {
  display: flex;
  flex-wrap: wrap;
  gap: 4rem;
  margin: 6rem 0;
}
@media all and (max-width: 900px) {
  .boxes {
    flex-direction: column;
    gap: 2.4rem;
    margin: 3rem 0;
  }
}

.box {
  position: relative;
  width: calc(50% - 2rem);
  height: 49rem;
  border-radius: 2rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .box {
    width: 100%;
    border-radius: 0.8rem;
    height: 28rem !important;
  }
}
.box--wide {
  width: 100%;
  height: 41rem;
}
.box__inner {
  display: block;
  height: 100%;
  color: #fff;
  text-decoration: none;
}
.box__inner2 {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 2;
  background-color: rgba(0, 0, 0, 0.6);
  display: flex;
  padding: 2rem 6rem 3rem;
  flex-direction: column;
  align-items: center;
  height: auto;
  transition-duration: 0.4s;
  border-radius: 2rem;
}
@media all and (max-width: 900px) {
  .box__inner2 {
    padding: 1.4rem 1.6rem;
    border-radius: 0.8rem;
    transition-duration: 0.6s;
  }
}
.box:hover .box__inner2 {
  height: 100%;
}
.box__ttl {
  flex-shrink: 0;
  margin-bottom: 0;
/*  font-size: 3.2rem; */
  font-size: 2.2rem;

  font-family: var(--font-mincho);
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .box__ttl {
  /*  font-size: 1.6rem; */
    font-size: 1.4rem;   
  }
}
.box__txt {
  flex-shrink: 0;
  font-size: 1.8rem;
  font-weight: 700;
  margin: 0;
}
@media all and (max-width: 900px) {
  .box__txt {
    font-size: 1.2rem;
    margin-top: 0.4rem;
  }
}
.box__txt2 {
  flex: 1 1 auto;
  display: none;
  min-height: 0;
  margin: 2.4rem 0 0;
  height: auto;
  overflow-y: auto;
  font-size: 1.8rem;
  font-weight: 700;
  opacity: 1;
  transition-duration: 0.75s;
  transition-delay: 0.1s;
}
@media all and (max-width: 900px) {
  .box__txt2 {
    margin-top: 1.4rem;
    font-size: 1.1rem;
  }
}
@starting-style {
  .box__txt2 {
    height: 0;
    opacity: 0;
  }
}
.box:hover .box__txt2 {
  display: block;
}
.box__btn {
  display: none;
  flex-shrink: 0;
  margin: 2.4rem 0 0;
  height: auto;
  opacity: 1;
  transition-duration: 0.5s;
  transition-delay: 0.1s;
}
@media all and (max-width: 900px) {
  .box__btn {
    margin-top: 1.4rem;
  }
}
@starting-style {
  .box__btn {
    height: 0;
    opacity: 0;
  }
}
.box__btn:hover {
  opacity: 0.8 !important;
  transition: 0.3s !important;
}
.box:hover .box__btn {
  display: block;
}
.box__img {
  position: absolute;
  inset: 0;
  z-index: 1;
}
.box__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
  -o-object-position: 50% 50%;
     object-position: 50% 50%;
}

.accordion {
  margin: 6rem 0;
  position: relative;
}
@media all and (max-width: 900px) {
  .accordion {
    margin: 3rem 0;
  }
}
.accordion + .accordion {
  margin-top: -6rem;
}
@media all and (max-width: 900px) {
  .accordion + .accordion {
    margin-top: -3rem;
  }
}
.accordion__ttl {
  position: relative;
  font-size: 2.2rem;
  padding: 2.2rem 8rem 2.4rem 4rem;
  background-color: #eff3f9;
  border-top: 0.4rem solid #0152a6;
  cursor: pointer;
}
@media all and (max-width: 900px) {
  .accordion__ttl {
    font-size: 1.3rem;
    padding: 1rem 3.2rem 1.2rem 1.6rem;
  }
}
.accordion__ttl::after {
  content: "";
  position: absolute;
  top: 0;
  bottom: 1rem;
  right: 2.8rem;
  margin: auto 0;
  width: 1.6rem;
  height: 1.6rem;
  border-right: 0.2rem solid #132c42;
  border-bottom: 0.2rem solid #132c42;
  transform: rotate(45deg);
  transition-duration: 0.3s;
}
@media all and (max-width: 900px) {
  .accordion__ttl::after {
    right: 1.4rem;
    width: 1rem;
    height: 1rem;
  }
}
.accordion__ttl.is-open::after {
  bottom: -0.4rem;
  transform: rotate(225deg);
}
@media all and (max-width: 900px) {
  .accordion__ttl.is-open::after {
    bottom: 0;
  }
}
.accordion__body {
  height: 0;
  overflow: hidden;
  font-size: 1.8rem;
  transition-duration: 0.3s;
}
@media all and (max-width: 900px) {
  .accordion__body {
    font-size: 1.1rem;
  }
}
.accordion__body.is-open {
  height: auto;
}
.accordion__body p {
  margin: 0;
}
.accordion__body__inner {
  padding: 2rem 4rem;
}
@media all and (max-width: 900px) {
  .accordion__body__inner {
    padding: 1.6rem 1.6rem;
  }
}

.profiles {
  display: flex;
  margin: 6rem 0;
  gap: 12rem;
}
@media all and (max-width: 900px) {
  .profiles {
    flex-direction: column;
    gap: 3rem;
    margin: 3rem 0;
  }
}

.profile {
  width: calc(50% - 6rem);
}
@media all and (max-width: 900px) {
  .profile {
    width: 100%;
  }
}
.profile__img {
  width: 100%;
  aspect-ratio: 400/460;
  border-radius: 1rem;
  overflow: hidden;
  margin-bottom: 2rem;
}
@media all and (max-width: 900px) {
  .profile__img {
    border-radius: 0.6rem;
    margin-bottom: 1.2rem;
  }
}
.profile__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.profile__ttl {
  font-size: 3.2rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  text-align: center;
  margin-bottom: 0.4rem;
}
@media all and (max-width: 900px) {
  .profile__ttl {
    margin-bottom: 0.2rem;
    font-size: 1.6rem;
  }
}
.profile__txt {
  font-size: 1.8rem;
  text-align: center;
  margin-bottom: 1.4rem;
}
@media all and (max-width: 900px) {
  .profile__txt {
    font-size: 1.2rem;
    margin-bottom: 1rem;
  }
}
.profile__btn {
  margin: 0;
  text-align: center;
}
.profile2__row {
  display: flex;
  align-items: flex-start;
  gap: 6rem;
}
@media all and (max-width: 900px) {
  .profile2__row {
    flex-direction: column;
    gap: 1.6rem;
  }
}
.profile2__img {
  width: 40rem;
  aspect-ratio: 400/460;
  border-radius: 1rem;
  overflow: hidden;
}
@media all and (max-width: 900px) {
  .profile2__img {
    width: 100%;
    aspect-ratio: 1/1;
    border-radius: 0.6rem;
  }
}
.profile2__img img {
  width: 100%;
  height: 100%;
  -o-object-fit: cover;
     object-fit: cover;
}
.profile2__col {
  flex: 1;
}
.profile2__ttl {
  font-size: 3.2rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  margin-bottom: 0;
}
@media all and (max-width: 900px) {
  .profile2__ttl {
    font-size: 1.6rem;
  }
}
.profile2__ttl2 {
  font-size: 2.2rem;
  font-weight: 700;
  margin: 3rem 0 1.8rem;
}
@media all and (max-width: 900px) {
  .profile2__ttl2 {
    font-size: 1.4rem;
    margin: 1rem 0 0.4rem;
  }
}
.profile2__txt {
  font-size: 1.8rem;
  margin-bottom: 1.4rem;
}
@media all and (max-width: 900px) {
  .profile2__txt {
    font-size: 1.2rem;
    margin-bottom: 1rem;
  }
}
.profile2__txt2 {
  font-size: 1.8rem;
  margin-bottom: 0;
}
@media all and (max-width: 900px) {
  .profile2__txt2 {
    font-size: 1rem;
  }
}

.profile-overlay {
  position: fixed;
  inset: 0;
  background: rgba(0, 0, 0, 0.6);
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 2.4rem;
  z-index: 1000;
  opacity: 0;
  visibility: hidden;
  transition: opacity 0.3s ease, visibility 0.3s ease;
}
@media all and (max-width: 900px) {
  .profile-overlay {
    padding: 2rem;
  }
}
.profile-overlay.is-open {
  opacity: 1;
  visibility: visible;
}
.profile-overlay__box {
  background: #fff;
  border-radius: 1.6rem;
  width: 100%;
  max-width: 103rem;
  max-height: 85vh;
  overflow-y: auto;
  padding: 6rem;
  box-shadow: 0 2rem 6rem rgba(0, 0, 0, 0.3);
  transform: scale(0.95);
  transition: transform 0.3s ease;
}
@media all and (max-width: 900px) {
  .profile-overlay__box {
    border-radius: 0.8rem;
    max-width: 100%;
    max-height: 100%;
    padding: 3.6rem 1.6rem 2rem;
  }
}
.profile-overlay.is-open .profile-overlay__box {
  transform: scale(1);
}
.profile-overlay__close {
  position: absolute;
  top: 2.4rem;
  right: 2.4rem;
  width: 3.6rem;
  height: 3.6rem;
  background: none;
  border: none;
  cursor: pointer;
  padding: 0;
}
@media all and (max-width: 900px) {
  .profile-overlay__close {
    top: 0.8rem;
    right: 1rem;
    width: 2rem;
    height: 2rem;
  }
}
.profile-overlay__close::before, .profile-overlay__close::after {
  content: "";
  position: absolute;
  top: 50%;
  left: 50%;
  width: 3.6rem;
  height: 0.2rem;
  background-color: #888;
  transition: background-color 0.3s ease;
}
@media all and (max-width: 900px) {
  .profile-overlay__close::before, .profile-overlay__close::after {
    width: 2rem;
  }
}
.profile-overlay__close::before {
  transform: translate(-50%, -50%) rotate(45deg);
}
.profile-overlay__close::after {
  transform: translate(-50%, -50%) rotate(-45deg);
}
.profile-overlay__close:hover::before, .profile-overlay__close:hover::after {
  background-color: #333;
}

.tag {
  display: flex;
  flex-wrap: wrap;
  gap: 1rem;
  margin: 0 0 3rem;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .tag {
    gap: 0.4rem;
    margin-bottom: 2.4rem;
  }
}
.tag--type2 {
  margin-bottom: 0;
}
@media all and (max-width: 900px) {
  .tag--type2 {
    margin-bottom: 0;
  }
}
.tag__item a {
  display: inline-block;
  padding: 0.5rem 1.6rem 0.7rem;
  font-size: 1.6rem;
  line-height: 1.2;
  text-decoration: none;
  border: 1px solid #0152a6;
  color: #0152a6;
  border-radius: 1.8rem;
}
@media all and (max-width: 900px) {
  .tag__item a {
    padding: 0.3rem 0.8rem 0.4rem;
    font-size: 1.1rem;
  }
}

.sns {
  margin: 8.8rem 0 0;
}
@media all and (max-width: 900px) {
  .sns {
    margin-top: 4.8rem;
  }
}
.sns__list {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 4.6rem;
  margin: 0;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .sns__list {
    gap: 1.6rem;
  }
}
.sns__list__item a {
  display: block;
  width: 7.1rem;
  height: 7.1rem;
  text-indent: -999rem;
  overflow: hidden;
  background: no-repeat 0 0;
  background-size: 100% 100%;
}

.message-thumb--live {
    margin-top: 2em !important;
}
@media all and (max-width: 900px) {
.message-thumb--live {
    margin-top: 2em !important;
}
}

@media all and (max-width: 900px) {
  .sns__list__item a {
    width: 4rem;
    height: 4rem;
  }
}
.sns__list__item--facebook a {
  background-image: url(../images/ic_facebook_001.png);
}
.sns__list__item--x a {
  background-image: url(../images/ic_x_001.png);
}
.sns__list__item--line a {
  background-image: url(../images/ic_line_001.png);
}


/* YouTube動画：中央寄せ＋レスポンシブ（横幅100%まで） */
.message-archive .article iframe {
    display: block;
    width: 100%;
    max-width: 560px;   /* PCでは560pxまで、スマホでは画面幅に追従 */
    aspect-ratio: 16 / 9;  /* 高さを自動計算（height属性は無視される） */
    height: auto;
    margin-inline: auto;   /* 中央寄せ */
}

/* お花の画像：中央寄せ */
.message-archive .article figure.wp-block-image {
    margin-inline: auto;
    text-align: center;
}

.message-archive .article figure.wp-block-image img {
    display: block;        /* ← これを追加 */
    max-width: 100%;
    height: auto;
    margin-inline: auto;   /* ← これを追加 */
}

/* message-archiveファイルブロック全体 */
/* ファイルブロック全体 */
.message-archive .article .wp-block-file {
    display: flex;
    align-items: center;
    justify-content: flex-start;
    gap: 0.5em;
    flex-wrap: wrap;      /* ← nowrap から wrap に戻す */
    padding: 1em 1.25em;
    border: 1px solid #0152a6;
    border-radius: 8px;
    background: #f4f8fc;
}

/* ファイル名テキスト（左側リンク） */
.message-archive .article .wp-block-file > a:not(.wp-block-file__button) {
    color: #0152a6;
    font-weight: 600;
    text-decoration: none;
    line-height: 1.5;
    flex: 1 1 auto;    /* ← ファイル名を1行分の幅いっぱいに */
    min-width: 0;
}

.message-archive .article .wp-block-file > a:not(.wp-block-file__button):hover {
    text-decoration: underline;
}

/* message-archiveダウンロードボタン */
/* ダウンロードボタン */
.message-archive .article .wp-block-file__button {
    display: inline-block;
    padding: 0.3em 0.8em;   /* ← 小さく */
    background: #0152a6;
    color: #fff;
    font-size: 0.75em;      /* ← 小さく */
    font-weight: 600;
    text-decoration: none;
    border: 1px solid #0152a6;
    border-radius: 6px;
    transition: background 0.2s, color 0.2s;
    white-space: nowrap;
}

.message-archive .article .wp-block-file__button:hover {
    background: #fff;
    color: #0152a6;
}


/* ============================================================
   .message-single ベース スタイル
   ・見出し h4 は .article 既存デザインを使うため未指定
   ・#0152a6基調 / YouTube 16:9 / お花センタリング /
     ダウンロードカード（PC横並び・SP折り返し）/ メディアクエリ不使用
   ============================================================ */

/* 日付 */
.message-single .message-date {
	color: #666;
	font-size: 14px;
	margin: 0 0 4px;
}
 

/* ライブ配信バッジ（中央寄せ・大きめ・目立たせる） */
.message-single .message-live-badge {
	display: block;
	text-align: center;
	background: #d93025;
	color: #fff;
	font-size: 22px;
	font-weight: 700;
	line-height: 1.4;
	padding: 14px 20px;
	border-radius: 8px;
	margin: 0 auto 24px;
}
 
/* メッセージ／巻頭言 本文 */
.message-single .message-sermon__body,
.message-single .message-foreword__body {
	line-height: 1.8;
}
.message-single .message-foreword__title {
	font-weight: 600;
	margin: 0 0 8px;
}
 
/* 氏名（右寄せ・メッセージ／巻頭言共通） */
.message-single .message-name {
	text-align: right;
	font-weight: 600;
	margin-top: 8px;
}
 
/* YouTube（16:9・中央寄せ・幅上限） */
.message-single .message-youtube {
	width: 100%;
/*	max-width: 560px; */
	aspect-ratio: 16 / 9;
	margin-inline: auto;
}
.message-single .message-youtube iframe {
	width: 100%;
	height: 100%;
	display: block;
}
 
/* プログラム ダウンロードカード
   PC：横並び ／ SP：ファイル名の下にボタンが折り返す */
.message-single .message-download {
	display: flex;
	flex-wrap: wrap;
	align-items: center;
	gap: 12px;
	background: #f2f7fc;
	border: 1px solid #0152a6;
	border-radius: 6px;
	padding: 14px 16px;
}
.message-single .message-download__name {
	flex: 1 1 auto;
	min-width: 0;
	font-weight: 600;
	word-break: break-word;
}
.message-single .message-download__btn {
	flex: 0 0 auto;
	display: inline-block;
	background: #0152a6;
	color: #fff;
	text-decoration: none;
	font-weight: 700;
	padding: 4px 20px;
	border-radius: 8px;
  font-size: 1.4rem;
}

@media all and (max-width: 900px) {
.message-single .message-download__btn {
	font-weight: 700;
	padding: 4px 20px;
	border-radius: 7px;
  font-size: 0.8rem;
}
}

.message-single .message-download__btn:hover {
	opacity: .88;
}
 
/* 今日のお花（画像センタリング）
   figureのtext-alignだけでは効かないためimgにmargin-inline */
.message-single .message-flower {
	margin: 0 auto;
  width: 500px;
}

@media all and (max-width: 900px) {
.message-single .message-flower {
  	margin: 0 auto;
  width: 80%;
}
}

.message-single .message-flower img {
	display: block;
	margin-inline: auto;
	max-width: 100%;
	height: auto;
}
 
/* アイキャッチ画像（1280×720の自作サムネイル） */
.message-single .message-thumb {
	margin: 0 0 20px;
}
.message-single .message-thumb img {
	display: block;
	width: 100%;
	height: auto;
	aspect-ratio: 16 / 9;
	object-fit: cover;
}
 
/* アーカイブ一覧：ライブ配信ラベル（サムネイル下・赤背景／白文字） */

/* 画像枠を包むラッパー。
   既存の .message2__list__img（幅・角丸・overflow）には触らない */
.message2__list__item .message2__list__imgwrap {
	display: block;
}

/* ラベル本体：赤背景・白文字・サムネイルと同じ横幅 */
.message2__list__item .message2__live {
	display: block;
	width: 100%;
	box-sizing: border-box;
	background: #d93025;
	color: #fff !important;
	font-weight: 700;
	text-align: center;
	font-size: 15px;
	line-height: 1.4;
	padding: 10px 12px;
	margin: 8px 0 0;
	border-radius: 6px;
	text-decoration: none;
}
 

.article {
  overflow: hidden;
  font-size: 1.8rem;
}
@media all and (max-width: 900px) {
  .article {
    font-size: 1.2rem;
  }
}
.article img {
  border-radius: 1.4rem;
}
@media all and (max-width: 900px) {
  .article img {
    border-radius: 0.7rem;
  }
}
.article h2 {
  position: relative;
  margin: 3.6rem 0;
  padding: 2rem 4rem;
  background-color: #eff3f9;
  border-radius: 1rem;
  overflow: hidden;
  color: #18589c;
  font-size: 2.4rem;
  font-family: var(--font-mincho);
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .article h2 {
    margin: 2rem 0;
    padding: 1.2rem;
    border-radius: 0.5rem;
    font-size: 1.4rem;
  }
}
.article h2::before {
  content: "";
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  height: 0.3rem;
  background-color: #18589c;
}
.article h3 {
  position: relative;
  margin: 3.6rem 0;
  padding: 0.8rem 2rem 2rem;
  color: #18589c;
  font-size: 2.4rem;
  font-family: var(--font-mincho);
  font-weight: 700;
  border-bottom: 0.4rem solid #eff3f9;
}
@media all and (max-width: 900px) {
  .article h3 {
    margin: 2rem 0;
    padding: 0.4rem 1.2rem 1.4rem;
    font-size: 1.4rem;
  }
}
.article h3::before {
  content: "";
  position: absolute;
  top: 0;
  bottom: 1rem;
  left: 0;
  width: 0.4rem;
  border-radius: 0.2rem;
  background-color: #18589c;
}
@media all and (max-width: 900px) {
  .article h3::before {
    bottom: 0.8rem;
    width: 0.3rem;
  }
}
.article h4 {
  margin: 3rem 0;
  padding-bottom: 1.6rem;
  color: #18589c;
  font-size: 2.2rem;
  font-weight: 700;
  border-bottom: 0.2rem solid #18589c;
}
@media all and (max-width: 900px) {
  .article h4 {
    margin: 1.8rem 0;
    padding-bottom: 0.8rem;
    font-size: 1.3rem;
  }
}
.article h5 {
  margin: 3rem 0;
  padding: 1.2rem 2rem;
  background-color: #eff3f9;
  border-radius: 1rem;
  color: #18589c;
  font-size: 2rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .article h5 {
    margin: 1.8rem 0;
    padding: 0.8rem 1.2rem;
    border-radius: 0.5rem;
    font-size: 1.3rem;
  }
}
.article h6 {
  margin: 3rem 0 2rem;
  color: #18589c;
  font-size: 2rem;
  font-weight: 700;
}
@media all and (max-width: 900px) {
  .article h6 {
    margin: 1.8rem 0 1.5rem;
    font-size: 1.3rem;
  }
}
.article ul {
  margin-bottom: 4rem;
  list-style-type: none;
}
@media all and (max-width: 900px) {
  .article ul {
    margin-bottom: 2.4rem;
  }
}
.article ul > li {
  position: relative;
  padding-left: 1.4rem;
  margin-left: 1.4rem;
}
.article ul > li:before {
  content: "";
  position: absolute;
  top: 0.65em;
  left: 0;
  width: 0.6rem;
  height: 0.6rem;
  border-radius: 50%;
  background: #18589c;
}
@media all and (max-width: 900px) {
  .article ul > li:before {
    width: 0.5rem;
    height: 0.5rem;
  }
}
.article ol {
  margin-bottom: 4rem;
}
@media all and (max-width: 900px) {
  .article ol {
    margin-bottom: 2.4rem;
  }
}
.article ol > li {
  list-style-type: decimal;
  margin-left: 2.5em;
}
.article blockquote {
  background-color: #fff;
  border-left: 0.4rem solid #18589c;
  padding: 2.4rem 4rem;
  margin: 6rem 0;
}
@media all and (max-width: 900px) {
  .article blockquote {
    border-width: 0.3rem;
    padding: 1.2rem;
    margin: 2.4rem 0;
  }
}
.article blockquote p, .article blockquote ul, .article blockquote ol, .article blockquote dl {
  margin-bottom: 0;
  margin-bottom: 0;
}
.article hr {
  clear: both;
  border: none;
  border-top: 0.2rem solid #18589c;
  margin: 6rem 0;
}
@media all and (max-width: 900px) {
  .article hr {
    border-top-width: 0.2rem;
    margin: 2.4rem 0;
  }
}
.article pre {
  background-color: #eff3f9;
  padding: 2.4rem 4rem;
  margin: 6rem 0;
  border-radius: 1.4rem;
  white-space: pre-wrap;
}
@media all and (max-width: 900px) {
  .article pre {
    padding: 1.2rem;
    margin: 2.4rem 0;
    border-radius: 0.7rem;
  }
}
.article .alignleft {
  clear: both;
  float: left;
  margin-right: 4rem;
  margin-bottom: 6rem;
}
@media all and (max-width: 900px) {
  .article .alignleft {
    float: none;
    display: block;
    margin-right: auto;
    margin-left: auto;
    max-width: 100%;
    width: 100%;
    height: auto;
    margin-bottom: 2.4rem;
  }
}
.article .aligncenter {
  display: table;
  clear: both;
  margin-left: auto;
  margin-right: auto;
  margin-bottom: 6rem;
  width: 72rem;
  height: auto;
}
@media all and (max-width: 900px) {
  .article .aligncenter {
    float: none;
    display: block;
    margin-right: auto;
    margin-left: auto;
    max-width: 100%;
    width: 100%;
    margin-bottom: 2.4rem;
  }
}
.article .alignright {
  clear: both;
  float: right;
  margin-left: 4rem;
  margin-bottom: 6em;
}
@media all and (max-width: 900px) {
  .article .alignright {
    float: none;
    display: block;
    margin-right: auto;
    margin-left: auto;
    max-width: 100%;
    width: 100%;
    height: auto;
    margin-bottom: 2.4rem;
  }
}
.article > :first-child {
  margin-top: 0;
}
.article > :last-child {
  margin-bottom: 0;
}

.kindergarten-page a,
.kindergarten-page a:hover,
.kindergarten-page a:visited,
.kindergarten-page .connect__block__ttl {
    color: #fff;
    text-decoration: none;
}


/* ===== Snow Monkey Forms カスタムCSS ===== */
.snow-monkey-form {
	max-width: 680px;
	margin: 0 auto;
	color: #333;
	font-size: 16px;
	line-height: 1.7;
}

/* --- 入力項目（PC・SP共通：見出しの下に入力欄） --- */
.smf-item {
	display: block;
	margin-bottom: 1.5em;
}
.smf-item__col--label,
.smf-item__col--controls {
	width: 100%;
	padding-right: 0;
}
.smf-item__label__text {
	display: inline-block;
	margin-bottom: 0.4em;
	font-weight: bold;
}
.smf-item__label__text::after {
	content: "*";
	margin-left: 0.3em;
	color: #d93025;
	font-weight: bold;
}

/* --- 入力コントロール --- */
.smf-text-control__control,
.smf-textarea-control__control {
	width: 100%;
	padding: 0.6em 0.8em;
	border: 1px solid #ccc;
	border-radius: 4px;
	font-size: 16px;
	line-height: 1.6;
	box-sizing: border-box;
	transition: border-color 0.2s;
}
.smf-text-control__control:focus,
.smf-textarea-control__control:focus {
	border-color: #0152a6;
	outline: none;
	box-shadow: 0 0 0 2px rgba(1, 82, 166, 0.15);
}
.smf-textarea-control__control {
	resize: vertical;
}

/* --- ボタン --- */
.smf-action {
	margin-top: 2em;
	text-align: center;
}
.smf-button-control__control {
	display: inline-block;
	min-width: 180px;
	padding: 0.8em 2em;
	border: 1px solid #0152a6;
	border-radius: 4px;
	background: #0152a6;
	color: #fff;
	font-size: 16px;
	font-weight: bold;
	cursor: pointer;
	transition: background 0.2s;
}
.smf-button-control__control:hover {
	background: #013d7a;
}
.smf-button-control--back .smf-button-control__control {
	background: #fff;
	color: #0152a6;
}
.smf-button-control--back .smf-button-control__control:hover {
	background: #eef3f9;
}

/* --- エラー・バリデーション --- */
.smf-invalid .smf-text-control__control,
.smf-invalid .smf-textarea-control__control {
	border-color: #d93025;
}
.smf-validation-error {
	display: block;
	margin-top: 0.3em;
	color: #d93025;
	font-size: 13px;
}
.smf-system-error-content-ready {
	display: none;
}

/* --- スマホ --- */
@media (max-width: 900px) {
	.smf-progress-tracker__item {
		font-size: 11px;
	}
}